#!/usr/bin/env python
# -*- coding: utf-8 -*-

class DisplayImg:
    """!
    @brief A class to represent and manage image display properties.
    """

    def __init__(self, w, h,overlap, img, side):
        """!
        @brief Constructor for the DisplayImg class.
        @param w The width of the display area.
        @param h The height of the display area.
        @param overlap The overlap percentage for the display area.
        @param img The image to be displayed.
        @param side The side or orientation of the display.
        """
        self.__p_width = w  
        self.__p_height = h
        self.__p_overlap = overlap
        self.__img = img
        self.__side = side

    def getImg(self):
        """!
        @brief Getter for the image.
        @return The image associated with the display.
        """
        return self.__img

    def getWidth(self):
        """!
        @brief Getter for the width of the display.
        @return The width of the display area.
        """
        return self.__p_width

    def getHeight(self):
        """!
        @brief Getter for the height of the display.
        @return The height of the display area.
        """
        return self.__p_height

    def getOverlap(self):
        """!
        @brief Getter for the overlap percentage.
        @return The overlap percentage of the display area.
        """
        return self.__p_overlap

    def getSide(self):
        """!
        @brief Getter for the side/orientation of the display.
        @return The side or orientation of the display.
        """
        return self.__side
